==> nextcloud-20.0.11.tgz: nextcloud/apps/twofactor_backupcodes/l10n/de.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "Du hast Zwei-Faktor Sicherungs-Codes für Dein Konto erstellt",
    "Second-factor backup codes" : "Zweitfaktor Backup-Codes",
    "Generate backup codes" : "Backup-Codes erzeugen",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Du hast die Zwei-Faktor-Authentifizierung aktiviert, aber noch keine Backup-Codes erzeugt. Diese werden für den Fall benötigt, dass Du den Zugriff auf Deinen zweiten Faktor verloren hast.",
    "Backup code" : "Backup-Code",
    "Use backup code" : "Verwende Backup-Code",
    "Two factor backup codes" : "Zweifaktor-Backup-Codes",
    "A two-factor auth backup codes provider" : "Ein Anbieter für Zweifaktor-Backup-Codes",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Backup-Codes wurden erzeugt. {used} von {total} Codes wurden benutzt.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Dies sind Deine Backup-Codes.  Bitte speichere und/oder drucke diese aus, da diese Codes später nicht mehr angezeigt werden können",
    "Save backup codes" : "Backup-Codes speichern",
    "Print backup codes" : "Backup-Codes drucken",
    "Regenerate backup codes" : "Backup-Codes erneuern",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Wenn Du Backup-Codes erneuerst, werden alte automatisch ungültig.",
    "An error occurred while generating your backup codes" : "Beim Erstellen Deiner Backup-Codes ist ein Fehler aufgetreten",
    "{name} backup codes" : "{name} Backup-Codes",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Verwende einen der Backup-Codes, den Du bei der Einrichtung der Zwei-Faktor-Authentifizierung gespeichert hast.",
    "Submit" : "Übermitteln"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-21.0.8p0.tgz: nextcloud/apps/twofactor_backupcodes/l10n/de.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "Du hast Zwei-Faktor Sicherungs-Codes für Dein Konto erstellt",
    "Second-factor backup codes" : "Zweitfaktor Backup-Codes",
    "Generate backup codes" : "Backup-Codes erzeugen",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Du hast die Zwei-Faktor-Authentifizierung aktiviert, aber noch keine Backup-Codes erzeugt. Diese werden für den Fall benötigt, dass Du den Zugriff auf Deinen zweiten Faktor verloren hast.",
    "Backup code" : "Backup-Code",
    "Use backup code" : "Verwende Backup-Code",
    "Two factor backup codes" : "Zweifaktor-Backup-Codes",
    "A two-factor auth backup codes provider" : "Ein Anbieter für Zweifaktor-Backup-Codes",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Backup-Codes wurden erzeugt. {used} von {total} Codes wurden benutzt.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Dies sind Deine Backup-Codes.  Bitte speichere und/oder drucke diese aus, da diese Codes später nicht mehr angezeigt werden können",
    "Save backup codes" : "Backup-Codes speichern",
    "Print backup codes" : "Backup-Codes drucken",
    "Regenerate backup codes" : "Backup-Codes erneuern",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Wenn Du Backup-Codes erneuerst, werden alte automatisch ungültig.",
    "An error occurred while generating your backup codes" : "Es ist ein Fehler beim Erstellen Deiner Backup-Codes aufgetreten",
    "{name} backup codes" : "{name} Backup-Codes",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Verwende einen der Backup-Codes, den Du bei der Einrichtung der Zwei-Faktor-Authentifizierung gespeichert hast.",
    "Submit" : "Übermitteln"
},
"nplurals=2; plural=(n != 1);");
